@@ -2,19 +2,25 @@
 #######################################################################
 """ Special widgets for maincontainer browser pages
 
-$Id: widgets.py 49278 2008-01-08 15:44:56Z cray $
+$Id: widgets.py 49612 2008-01-21 12:55:05Z cray $
 """
 __author__  = u"Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49278 $"
+__version__ = "$Revision: 49612 $"
 
 from zope.app.form import CustomWidgetFactory
-from zope.app.form.browser import ObjectWidget
+from ng.lib.objectwidget import ObjectWidget
 from zope.app.form.browser import TupleSequenceWidget
 from ng.content.article.maincontainer.urldescriptor import UrlDescriptor
+from zope.app.file.image import Image
 
 UrlDescriptorTupleWidget = CustomWidgetFactory(
    TupleSequenceWidget,
    subwidget=CustomWidgetFactory(
                     ObjectWidget,
                     UrlDescriptor))
+
+LogoWidget = CustomWidgetFactory(
+    ObjectWidget,
+    Image
+    )
