@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based ng.content.article.maincontainer package
 
-$Id: interfaces.py 49278 2008-01-08 15:44:56Z cray $
+$Id: interfaces.py 49612 2008-01-21 12:55:05Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49278 $"
+__version__ = "$Revision: 49612 $"
 
 from zope.interface import Interface
 
@@ -21,6 +21,8 @@ from zope.app.component.interfaces import IPossibleSite
 from zope.app.container.interfaces import IOrderedContainer
 from ng.content.article.interfaces import IDocTitle, IDocAbstract
 
+from zope.app.file.interfaces import IImage
+
 class IMainSwitcher(Interface) :
     """ Interface of Maincontainer
     """
@@ -94,4 +96,8 @@ class IMainPage(IDocTitle,IDocAbstract) :
         description=u'Design Choice',
         required = False)
 
-
+    logo = Object(
+        title = u"Logo",
+        description = u"Logo",
+        schema = IImage,
+        )
